EXPORTS
	?CreateAppUi@@YAPAVCEikServAppUi@@XZ @ 1 NONAME ; class CEikServAppUi * __cdecl CreateAppUi(void)
	?SuppressAppSwitching@CEikServAppUi@@QAEXH@Z @ 2 NONAME ; public: void __thiscall CEikServAppUi::SuppressAppSwitching(int)
	?RegisterNotifierControllerPlugin@CAknNotifierController@@QAEXPAVCAknNotifierWrapper@@H@Z @ 3 NONAME ; void CAknNotifierController::RegisterNotifierControllerPlugin(class CAknNotifierWrapper *, int)
	?ActivateDisplayIfNeeded@CEikServAppUi@@QAEXXZ @ 4 NONAME ; public: void __thiscall CEikServAppUi::ActivateDisplayIfNeeded(void)
	?HideApplicationFromFswL@CEikServAppUi@@QAEXHH@Z @ 5 NONAME ; public: void __thiscall CEikServAppUi::HideApplicationFromFswL(int,int)
	?StartNewServerApplicationL@CEikServAppUi@@QAEXVTUid@@@Z @ 6 NONAME ; void CEikServAppUi::StartNewServerApplicationL(class TUid)
	??0CEikServAppUiBase@@IAE@XZ @ 7 NONAME ; CEikServAppUiBase::CEikServAppUiBase(void)
	??1CEikServAppUiBase@@UAE@XZ @ 8 NONAME ; CEikServAppUiBase::~CEikServAppUiBase(void)
	?BlankScreenL@CEikServAppUiBase@@UAEXXZ @ 9 NONAME ; void CEikServAppUiBase::BlankScreenL(void)
	?BringAlertGroupWinForwards@CEikServAppUiBase@@QAEXH@Z @ 10 NONAME ; void CEikServAppUiBase::BringAlertGroupWinForwards(int)
	?ConstructL@CEikServAppUiBase@@MAEXXZ @ 11 NONAME ; void CEikServAppUiBase::ConstructL(void)
	?CreateSessionL@CEikServAppUi@@UAEPAVCEikServAppUiSession@@XZ @ 12 NONAME ; class CEikServAppUiSession * CEikServAppUi::CreateSessionL(void)
	?CycleTasksL@CEikServAppUiBase@@UAEXW4TTaskCycleDirection@@@Z @ 13 NONAME ; void CEikServAppUiBase::CycleTasksL(enum TTaskCycleDirection)
	?EnableTaskListL@CEikServAppUiBase@@UAEXXZ @ 14 NONAME ; void CEikServAppUiBase::EnableTaskListL(void)
	?HandleApplicationSpecificEventL@CEikServAppUiBase@@EAEXHABVTWsEvent@@@Z @ 15 NONAME ; void CEikServAppUiBase::HandleApplicationSpecificEventL(int, class TWsEvent const &)
	?HandleForegroundEventL@CEikServAppUiBase@@UAEXH@Z @ 16 NONAME ; void CEikServAppUiBase::HandleForegroundEventL(int)
	?HandleKeyEventL@CEikServAppUiBase@@EAE?AW4TKeyResponse@@ABUTKeyEvent@@W4TEventCode@@@Z @ 17 NONAME ; enum TKeyResponse CEikServAppUiBase::HandleKeyEventL(struct TKeyEvent const &, enum TEventCode)
	?HandleResourceChangeL@CEikServAppUiBase@@MAEXH@Z @ 18 NONAME ; void CEikServAppUiBase::HandleResourceChangeL(int)
	?HandleSwitchOnEventL@CEikServAppUiBase@@EAEXPAVCCoeControl@@@Z @ 19 NONAME ; void CEikServAppUiBase::HandleSwitchOnEventL(class CCoeControl *)
	?HandleSystemEventL@CEikServAppUiBase@@EAEXABVTWsEvent@@@Z @ 20 NONAME ; void CEikServAppUiBase::HandleSystemEventL(class TWsEvent const &)
	?HandleThreadExitL@CEikServAppUiBase@@MAEXAAVRThread@@@Z @ 21 NONAME ; void CEikServAppUiBase::HandleThreadExitL(class RThread &)
	?HandleWsEventL@CEikServAppUiBase@@MAEXABVTWsEvent@@PAVCCoeControl@@@Z @ 22 NONAME ; void CEikServAppUiBase::HandleWsEventL(class TWsEvent const &, class CCoeControl *)
	?InitializeL@CEikServAppUiBase@@IAEXAAVTEikServCtrlFactories@@@Z @ 23 NONAME ; void CEikServAppUiBase::InitializeL(class TEikServCtrlFactories &)
	?LaunchTaskListL@CEikServAppUiBase@@UAEXXZ @ 24 NONAME ; void CEikServAppUiBase::LaunchTaskListL(void)
	?NewLC@CEikServAppUiBase@@SAPAV1@XZ @ 25 NONAME ; class CEikServAppUiBase * CEikServAppUiBase::NewLC(void)
	?NotifyAlarmServerOfTaskChangeL@CEikServAppUiBase@@UAEXXZ @ 26 NONAME ; void CEikServAppUiBase::NotifyAlarmServerOfTaskChangeL(void)
	?SetStatusPaneFlags@CEikServAppUiBase@@UAEXH@Z @ 27 NONAME ; void CEikServAppUiBase::SetStatusPaneFlags(int)
	?SetStatusPaneLayoutL@CEikServAppUiBase@@UAEXH@Z @ 28 NONAME ; void CEikServAppUiBase::SetStatusPaneLayoutL(int)
	?ShutdownAppsL@CEikServAppUiBase@@QAEXVTUid@@ABVRMessage2@@H@Z @ 29 NONAME ; void CEikServAppUiBase::ShutdownAppsL(class TUid, class RMessage2 const &, int)
	?UnblankScreen@CEikServAppUiBase@@UAEXXZ @ 30 NONAME ; void CEikServAppUiBase::UnblankScreen(void)

